Actions
=======

.. contents:: :local:

:mod:`add_config` Action
------------------------

.. automodule:: ztps.add_config
    :members:

:mod:`copy_file` Action
------------------------

.. automodule:: ztps.copy_file
    :members:

:mod:`install_cli_plugin` Action
--------------------------------

.. automodule:: ztps.install_cli_plugin
    :members:

:mod:`install_extension` Action
-------------------------------

.. automodule:: ztps.install_extension
    :members:

:mod:`install_image` Action
---------------------------

.. automodule:: ztps.install_image
    :members:

:mod:`replace_config` Action
----------------------------

.. automodule:: ztps.replace_config
    :members:

:mod:`send_email` Action
------------------------

.. automodule:: ztps.send_email
    :members:

..
   #:mod:`template` Action
   #----------------------
   #
   #.. automodule:: template
   #    :members:

